==> tfx-cli-0.1.2.tgz: package/lib/diskcache.js <==
var Q = require('q');
var fs = require('fs');
var osHomedir = require('os-homedir');
var path = require('path');
var shell = require('shelljs');
var DiskCache = (function () {
    function DiskCache(appName) {
        this.appName = appName;
    }
    DiskCache.prototype.getFilePath = function (store, name) {
        var storeFolder = path.join(osHomedir(), '.' + this.appName, store);
        shell.mkdir('-p', storeFolder);
        return path.join(storeFolder, '.' + name);
    };
    DiskCache.prototype.itemExists = function (store, name) {
        var defer = Q.defer();
        fs.exists(this.getFilePath(store, name), function (exists) {
            defer.resolve(exists);
        });
        return defer.promise;
    };
    DiskCache.prototype.getItem = function (store, name) {
        var defer = Q.defer();
        fs.readFile(this.getFilePath(store, name), function (err, contents) {
            if (err) {
                defer.reject(err);
                return;
            }
            defer.resolve(contents.toString());
        });
        return defer.promise;
    };
    DiskCache.prototype.setItem = function (store, name, data) {
        var defer = Q.defer();
        fs.writeFile(this.getFilePath(store, name), data, { flag: 'w' }, function (err) {
            if (err) {
                defer.reject(err);
                return;
            }
            defer.resolve(null);
        });
        return defer.promise;
    };
    DiskCache.prototype.deleteItem = function (store, name) {
        // TODO
        var defer = Q.defer();
        defer.reject(new Error('Not implemented'));
        return defer.promise;
    };
    return DiskCache;
})();
exports.DiskCache = DiskCache;

==> tfx-cli-0.1.4.tgz: package/lib/diskcache.js <==
var Q = require('q');
var fs = require('fs');
var osHomedir = require('os-homedir');
var path = require('path');
var shell = require('shelljs');
var trace = require('./trace');
var DiskCache = (function () {
    function DiskCache(appName) {
        this.appName = appName;
    }
    DiskCache.prototype.getFilePath = function (store, name) {
        var storeFolder = path.join(osHomedir(), '.' + this.appName, store);
        shell.mkdir('-p', storeFolder);
        return path.join(storeFolder, '.' + name);
    };
    DiskCache.prototype.itemExists = function (store, name) {
        var defer = Q.defer();
        fs.exists(this.getFilePath(store, name), function (exists) {
            defer.resolve(exists);
        });
        return defer.promise;
    };
    DiskCache.prototype.getItem = function (store, name) {
        var defer = Q.defer();
        var fp = this.getFilePath(store, name);
        trace('read: ' + store + ':' + name);
        trace(fp);
        fs.readFile(fp, function (err, contents) {
            if (err) {
                defer.reject(err);
                return;
            }
            var str = contents.toString();
            trace(str);
            defer.resolve(str);
        });
        return defer.promise;
    };
    DiskCache.prototype.setItem = function (store, name, data) {
        var defer = Q.defer();
        var fp = this.getFilePath(store, name);
        trace('write: ' + store + ':' + name + ':' + data);
        trace(fp);
        fs.writeFile(fp, data, { flag: 'w' }, function (err) {
            if (err) {
                defer.reject(err);
                return;
            }
            trace('written');
            defer.resolve(null);
        });
        return defer.promise;
    };
    DiskCache.prototype.deleteItem = function (store, name) {
        // TODO
        var defer = Q.defer();
        defer.reject(new Error('Not implemented'));
        return defer.promise;
    };
    return DiskCache;
})();
exports.DiskCache = DiskCache;
